import{P as k}from"./api.af038271.js";import{b as _}from"./workspaceStore.415b10dd.js";import{d as w,L as g,N as l,e as v,o as r,X as h,b as s,w as T,u as e,c as p,R as m,$ as K}from"./vue-router.25496eb3.js";import{K as R,_ as I,W as P,P as S,b as V}from"./WorkflowView.f730ffb3.js";import{A as b,T as x}from"./TabPane.14d0acc8.js";import"./Card.559ad1ed.js";import"./fetch.e549f582.js";import"./metadata.b8c76de9.js";import"./PhBug.vue.ad71e707.js";import"./PhCheckCircle.vue.6921fc7d.js";import"./PhKanban.vue.6fea618a.js";import"./PhWebhooksLogo.vue.b74c61e7.js";import"./url.d7b430c5.js";import"./colorHelpers.9e2a2fd7.js";import"./polling.126e47fa.js";import"./asyncComputed.ee6673cb.js";import"./PhQuestion.vue.c5d97b7e.js";import"./ant-design.62a6773b.js";import"./index.cdda9ded.js";import"./index.cdaff782.js";import"./index.3eebd9d7.js";import"./CollapsePanel.85414ad6.js";import"./index.19636f37.js";import"./index.ad1f0c49.js";import"./Badge.0b8e6d1d.js";import"./PhArrowCounterClockwise.vue.cfe21b1b.js";import"./Workflow.57b2c37d.js";import"./validations.6af62ab2.js";import"./string.cb42bbf3.js";import"./uuid.bf5fabdb.js";import"./index.45b30c39.js";import"./workspaces.d28e8422.js";import"./record.0cf3393b.js";import"./index.612517b4.js";import"./PhArrowDown.vue.a5954681.js";import"./LoadingOutlined.ac39ec74.js";import"./DeleteOutlined.bb06588f.js";import"./PhDownloadSimple.vue.06d0f220.js";import"./utils.11bfdea6.js";import"./LoadingContainer.f24b0357.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[n]="44ba5469-20ab-405e-bccb-a8f118991fa1",t._sentryDebugIdIdentifier="sentry-dbid-44ba5469-20ab-405e-bccb-a8f118991fa1")}catch{}})();const W={class:"threads-view"},A=w({__name:"Threads",setup(t){const o=_().authHeaders,u=new k(o),i=new S(o),d=new V(o),y=new g(l.array(l.string()),"kanban-selected-stages"),a=v("kanban");return(B,c)=>(r(),h("div",W,[s(e(x),{activeKey:a.value,"onUpdate:activeKey":c[0]||(c[0]=f=>a.value=f)},{default:T(()=>[s(e(b),{key:"kanban",tab:"Kanban View"}),s(e(b),{key:"table",tab:"Table View"}),s(e(b),{key:"workflow",tab:"Workflow View"})]),_:1},8,["activeKey"]),a.value==="kanban"?(r(),p(R,{key:0,"kanban-repository":e(i),"kanban-stages-storage":e(y),"stage-run-repository":e(d)},null,8,["kanban-repository","kanban-stages-storage","stage-run-repository"])):m("",!0),a.value==="table"?(r(),p(I,{key:1,"kanban-repository":e(i)},null,8,["kanban-repository"])):m("",!0),a.value==="workflow"?(r(),p(P,{key:2,"kanban-repository":e(i),"workflow-api":e(u)},null,8,["kanban-repository","workflow-api"])):m("",!0)]))}});const ge=K(A,[["__scopeId","data-v-d6c18c3e"]]);export{ge as default};
//# sourceMappingURL=Threads.d2b5d9da.js.map
