import{a as g}from"./asyncComputed.ee6673cb.js";import{d as y,ea as _,W as b,u as e,o as l,c as w,X as x,b as a,w as o,dc as C,aF as p,dg as h,bS as I,a as k,e9 as v}from"./vue-router.25496eb3.js";import"./gateway.090a2504.js";import{O as B}from"./organization.88c8710e.js";import"./tables.732c3160.js";import{C as c}from"./router.92b9eafd.js";import{L as D}from"./LoadingContainer.f24b0357.js";import{A as N}from"./index.19636f37.js";import{C as z}from"./Card.559ad1ed.js";import"./popupNotifcation.ea7de34e.js";import"./record.0cf3393b.js";import"./string.cb42bbf3.js";import"./TabPane.14d0acc8.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[n]="17761c1e-e7b9-4e22-9ba5-f78dce4b5b55",t._sentryDebugIdIdentifier="sentry-dbid-17761c1e-e7b9-4e22-9ba5-f78dce4b5b55")}catch{}})();const M={key:1},A={style:{display:"flex","justify-content":"flex-start","font-size":"24px"}},H=y({__name:"Billing",setup(t){const s=_().params.organizationId,{loading:u,result:f}=g(()=>B.get(s));b(()=>{location.search.includes("upgrade")&&c.showNewMessage("I want to upgrade my plan")});const m=()=>c.showNewMessage("I want to upgrade my plan");return(V,j)=>e(u)?(l(),w(D,{key:0})):(l(),x("div",M,[a(e(h),{justify:"space-between",align:"center"},{default:o(()=>[a(e(C),{level:3},{default:o(()=>[p("Current plan")]),_:1})]),_:1}),a(e(N),{style:{"margin-top":"0"}}),a(e(z),{style:{width:"300px"},title:"Plan"},{extra:o(()=>[a(e(I),{onClick:m},{default:o(()=>[p("Upgrade")]),_:1})]),default:o(()=>{var r,i,d;return[k("div",A,v((d=(i=(r=e(f))==null?void 0:r.billingMetadata)==null?void 0:i.plan)!=null?d:"No active plan"),1)]}),_:1})]))}});export{H as default};
//# sourceMappingURL=Billing.27499f20.js.map
