import{E as y}from"./api.af038271.js";import{C as c}from"./ContentLayout.80f1caf4.js";import{d as w,L as g,N as l,e as _,o as e,c as i,w as f,b as n,u as o,R as s}from"./vue-router.25496eb3.js";import{K as v,_ as K,W as R,E,a as T}from"./WorkflowView.f730ffb3.js";import{A as p,T as V}from"./TabPane.14d0acc8.js";import"./fetch.e549f582.js";import"./metadata.b8c76de9.js";import"./PhBug.vue.ad71e707.js";import"./PhCheckCircle.vue.6921fc7d.js";import"./PhKanban.vue.6fea618a.js";import"./PhWebhooksLogo.vue.b74c61e7.js";import"./polling.126e47fa.js";import"./asyncComputed.ee6673cb.js";import"./PhQuestion.vue.c5d97b7e.js";import"./ant-design.62a6773b.js";import"./index.cdda9ded.js";import"./index.cdaff782.js";import"./index.3eebd9d7.js";import"./CollapsePanel.85414ad6.js";import"./index.19636f37.js";import"./index.ad1f0c49.js";import"./Badge.0b8e6d1d.js";import"./PhArrowCounterClockwise.vue.cfe21b1b.js";import"./Workflow.57b2c37d.js";import"./validations.6af62ab2.js";import"./string.cb42bbf3.js";import"./uuid.bf5fabdb.js";import"./index.45b30c39.js";import"./workspaces.d28e8422.js";import"./workspaceStore.415b10dd.js";import"./url.d7b430c5.js";import"./colorHelpers.9e2a2fd7.js";import"./record.0cf3393b.js";import"./index.612517b4.js";import"./PhArrowDown.vue.a5954681.js";import"./Card.559ad1ed.js";import"./LoadingOutlined.ac39ec74.js";import"./DeleteOutlined.bb06588f.js";import"./PhDownloadSimple.vue.06d0f220.js";import"./utils.11bfdea6.js";import"./LoadingContainer.f24b0357.js";(function(){try{var r=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(r._sentryDebugIds=r._sentryDebugIds||{},r._sentryDebugIds[t]="73e2bdca-b30f-436b-8f44-0eacc8684a48",r._sentryDebugIdIdentifier="sentry-dbid-73e2bdca-b30f-436b-8f44-0eacc8684a48")}catch{}})();const yo=w({__name:"WorkflowThreads",setup(r){const t=new E,m=new T,u=new g(l.array(l.string()),"kanban-selected-stages"),k=new y,a=_("kanban");return(W,b)=>(e(),i(c,{"full-width":""},{default:f(()=>[n(o(V),{activeKey:a.value,"onUpdate:activeKey":b[0]||(b[0]=d=>a.value=d)},{default:f(()=>[n(o(p),{key:"kanban",tab:"Kanban View"}),n(o(p),{key:"table",tab:"Table View"}),n(o(p),{key:"workflow",tab:"Workflow View"})]),_:1},8,["activeKey"]),a.value==="kanban"?(e(),i(v,{key:0,"kanban-repository":o(t),"kanban-stages-storage":o(u),"stage-run-repository":o(m)},null,8,["kanban-repository","kanban-stages-storage","stage-run-repository"])):s("",!0),a.value==="table"?(e(),i(K,{key:1,"kanban-repository":o(t)},null,8,["kanban-repository"])):s("",!0),a.value==="workflow"?(e(),i(R,{key:2,"kanban-repository":o(t),"workflow-api":o(k)},null,8,["kanban-repository","workflow-api"])):s("",!0)]),_:1}))}});export{yo as default};
//# sourceMappingURL=WorkflowThreads.e3566346.js.map
