import{_}from"./Login.vue_vue_type_script_setup_true_lang.14b1dbc1.js";import{b as f,u as m}from"./workspaceStore.415b10dd.js";import{d as l,eo as b,ea as y,o as g,X as w,b as k,u,$ as h}from"./vue-router.25496eb3.js";import"./Logo.3593edcd.js";import"./string.cb42bbf3.js";import"./CircularLoading.cd1bfded.js";import"./index.45b30c39.js";import"./index.7e4133e5.js";import"./url.d7b430c5.js";import"./colorHelpers.9e2a2fd7.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="6a9ecb4b-5778-45fb-8fed-62586ba53773",e._sentryDebugIdIdentifier="sentry-dbid-6a9ecb4b-5778-45fb-8fed-62586ba53773")}catch{}})();const v={class:"runner"},I=l({__name:"Login",setup(e){const o=b(),r=y(),i=f(),a=m(),p=async()=>{await i.signUp();const{redirect:t,...s}=r.query;if(t){await o.push({path:t,query:s,params:r.params});return}o.push({name:"playerHome",query:s})};return(t,s)=>{var n,c,d;return g(),w("div",v,[k(_,{"logo-url":(c=(n=u(a).state.workspace)==null?void 0:n.logoUrl)!=null?c:void 0,"brand-name":(d=u(a).state.workspace)==null?void 0:d.brandName,onDone:p},null,8,["logo-url","brand-name"])])}}});const $=h(I,[["__scopeId","data-v-fc57ade6"]]);export{$ as default};
//# sourceMappingURL=Login.e93c94b8.js.map
