import{d as r,o,c as d,w as a,b as f,Z as u,u as s,dg as i,ey as l,eB as c,bS as p}from"./vue-router.25496eb3.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="ee9bf373-42d3-4c98-890e-2b9f75a15a52",e._sentryDebugIdIdentifier="sentry-dbid-ee9bf373-42d3-4c98-890e-2b9f75a15a52")}catch{}})();const y=r({__name:"AbstraButton",setup(e){return(t,n)=>(o(),d(s(p),l(c(t.$attrs)),{default:a(()=>[f(s(i),{style:{display:"flex","align-items":"center","justify-content":"center",gap:"5px"}},{default:a(()=>[u(t.$slots,"default")]),_:3})]),_:3},16))}});export{y as _};
//# sourceMappingURL=AbstraButton.vue_vue_type_script_setup_true_lang.811b7ee7.js.map
