import{d as i,o as p,c as a,w as n,b as m,u as t}from"./vue-router.25496eb3.js";import"./editor.6d5ece39.js";import{W as s}from"./workspaces.d28e8422.js";import{C as d}from"./ContentLayout.80f1caf4.js";import{_ as f,E as u}from"./View.vue_vue_type_script_setup_true_lang.b7bf3ca0.js";import"./workspaceStore.415b10dd.js";import"./url.d7b430c5.js";import"./colorHelpers.9e2a2fd7.js";import"./asyncComputed.ee6673cb.js";import"./record.0cf3393b.js";import"./gateway.090a2504.js";import"./popupNotifcation.ea7de34e.js";import"./fetch.e549f582.js";import"./SaveButton.9c3cbf51.js";import"./UnsavedChangesHandler.60d82060.js";import"./ExclamationCircleOutlined.e0608e5b.js";import"./CrudView.cf099838.js";import"./router.92b9eafd.js";import"./DocsButton.vue_vue_type_script_setup_true_lang.c4306070.js";import"./BookOutlined.23f627d4.js";import"./PhDotsThreeVertical.vue.eb15d37e.js";import"./Badge.0b8e6d1d.js";import"./index.cdda9ded.js";import"./polling.126e47fa.js";import"./PhPencil.vue.a781bcff.js";import"./index.7e4133e5.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[r]="bbd64a22-9da5-4efa-a987-a999fb00e679",o._sentryDebugIdIdentifier="sentry-dbid-bbd64a22-9da5-4efa-a987-a999fb00e679")}catch{}})();const F=i({__name:"EnvVarsEditor",setup(o){const r=new u;return(e,c)=>(p(),a(d,null,{default:n(()=>[m(f,{"env-var-repository":t(r),mode:"editor","file-opener":t(s)},null,8,["env-var-repository","file-opener"])]),_:1}))}});export{F as default};
//# sourceMappingURL=EnvVarsEditor.5a94d415.js.map
