import{S as c,dA as s,dB as i}from"./vue-router.25496eb3.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="7cb56d19-5f0b-4ea2-b3ed-1bd8998edc4b",e._sentryDebugIdIdentifier="sentry-dbid-7cb56d19-5f0b-4ea2-b3ed-1bd8998edc4b")}catch{}})();const{DatePicker:n,WeekPicker:t,MonthPicker:r,YearPicker:b,TimePicker:f,QuarterPicker:d,RangePicker:o}=s(i),u=c(n,{WeekPicker:t,MonthPicker:r,YearPicker:b,RangePicker:o,TimePicker:f,QuarterPicker:d,install:e=>(e.component(n.name,n),e.component(o.name,o),e.component(r.name,r),e.component(t.name,t),e.component(d.name,d),e)});export{u as D,r as M,d as Q,o as R,t as W};
//# sourceMappingURL=dayjs.a6fb791f.js.map
