import{d as a,o,X as s,b as d,u as r,bx as _,$ as c}from"./vue-router.25496eb3.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="5159ebc8-6821-446b-b49a-ca26d62fb1d4",e._sentryDebugIdIdentifier="sentry-dbid-5159ebc8-6821-446b-b49a-ca26d62fb1d4")}catch{}})();const i={class:"centered"},b=a({__name:"LoadingContainer",setup(e){return(n,t)=>(o(),s("div",i,[d(r(_))]))}});const p=c(b,[["__scopeId","data-v-52e6209a"]]);export{p as L};
//# sourceMappingURL=LoadingContainer.f24b0357.js.map
