import{O as d}from"./workspaceStore.415b10dd.js";import{d as l,W as i,o as u,X as c,b as a,w as o,u as n,aF as s,dc as f,db as b}from"./vue-router.25496eb3.js";import"./url.d7b430c5.js";import"./colorHelpers.9e2a2fd7.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="e8ba8f69-e532-48ff-9c15-d4fb3eb1bc2e",e._sentryDebugIdIdentifier="sentry-dbid-e8ba8f69-e532-48ff-9c15-d4fb3eb1bc2e")}catch{}})();const w=l({__name:"OidcLogoutCallback",setup(e){return i(async()=>{await new d().logoutCallback()}),(t,r)=>(u(),c("div",null,[a(n(f),null,{default:o(()=>[s("You're authenticated")]),_:1}),a(n(b),null,{default:o(()=>[s(" This window should close automatically. Please close it manually if it doesn't. ")]),_:1})]))}});export{w as default};
//# sourceMappingURL=OidcLogoutCallback.08588f3e.js.map
