import{k as a,T as n,m as r,P as o,C as d,M as p,s as c,n as s,p as f,q as m,t as u,v as g}from"./vue-router.25496eb3.js";import{s as y,c as l,a as i}from"./workspaceStore.415b10dd.js";import{_ as b}from"./App.vue_vue_type_style_index_0_lang.4a2811c8.js";import"./url.d7b430c5.js";import"./colorHelpers.9e2a2fd7.js";import"./PlayerConfigProvider.1e86cb18.js";import"./index.45b30c39.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[e]="b8f8875a-6746-4e8d-896c-c34afd452830",t._sentryDebugIdIdentifier="sentry-dbid-b8f8875a-6746-4e8d-896c-c34afd452830")}catch{}})();class w{static init(){setInterval(()=>fetch("/_version"),20*1e3)}}(async()=>{await y();const t=l(),e=a({render:()=>f(b)});n.init(),r(e,i),w.init(),e.use(i),e.use(t),e.use(o),e.mount("#app"),e.component("VSelect",d),e.component("Markdown",p),e.component("Message",c),s(e,m),s(e,u),s(e,g)})();
//# sourceMappingURL=player.65be8a23.js.map
