import{B as n,R as t}from"./Badge.0b8e6d1d.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},b=new Error().stack;b&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[b]="2bed83ac-3430-4bae-9843-4cac18b1a2bb",e._sentryDebugIdIdentifier="sentry-dbid-2bed83ac-3430-4bae-9843-4cac18b1a2bb")}catch{}})();n.install=function(e){return e.component(n.name,n),e.component(t.name,t),e};
//# sourceMappingURL=index.612517b4.js.map
