import{d as n,o as s,X as a,a as d,Z as c,ed as f,$ as r}from"./vue-router.25496eb3.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="f89ab9ac-f2f7-4c9f-9e50-c881c90341fd",e._sentryDebugIdIdentifier="sentry-dbid-f89ab9ac-f2f7-4c9f-9e50-c881c90341fd")}catch{}})();const l={class:"content-layout"},_=n({__name:"ContentLayout",props:{fullWidth:{type:Boolean}},setup(e){return(t,o)=>(s(),a("div",l,[d("div",{class:f(["centered-layout",{"full-width":t.fullWidth}])},[c(t.$slots,"default",{},void 0,!0)],2)]))}});const i=r(_,[["__scopeId","data-v-6397d501"]]);export{i as C};
//# sourceMappingURL=ContentLayout.80f1caf4.js.map
