import{_ as n,C as p}from"./View.vue_vue_type_script_setup_true_lang.b7bf3ca0.js";import{d as i,ea as s,o as m,c as a,u as c}from"./vue-router.25496eb3.js";import"./gateway.090a2504.js";import"./popupNotifcation.ea7de34e.js";import"./fetch.e549f582.js";import"./record.0cf3393b.js";import"./SaveButton.9c3cbf51.js";import"./UnsavedChangesHandler.60d82060.js";import"./ExclamationCircleOutlined.e0608e5b.js";import"./CrudView.cf099838.js";import"./router.92b9eafd.js";import"./DocsButton.vue_vue_type_script_setup_true_lang.c4306070.js";import"./BookOutlined.23f627d4.js";import"./url.d7b430c5.js";import"./PhDotsThreeVertical.vue.eb15d37e.js";import"./Badge.0b8e6d1d.js";import"./index.cdda9ded.js";import"./asyncComputed.ee6673cb.js";import"./polling.126e47fa.js";import"./PhPencil.vue.a781bcff.js";import"./index.7e4133e5.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[e]="0c8c16f7-5a07-4ef0-98f3-1e9ece4bd335",o._sentryDebugIdIdentifier="sentry-dbid-0c8c16f7-5a07-4ef0-98f3-1e9ece4bd335")}catch{}})();const z=i({__name:"EnvVars",setup(o){const r=s().params.projectId,t=new p(r);return(d,f)=>(m(),a(n,{"env-var-repository":c(t),mode:"console"},null,8,["env-var-repository"]))}});export{z as default};
//# sourceMappingURL=EnvVars.3aa6bb92.js.map
