import"./App.vue_vue_type_style_index_0_lang.4a2811c8.js";import{_ as u}from"./App.vue_vue_type_style_index_0_lang.4a2811c8.js";import"./workspaceStore.415b10dd.js";import"./vue-router.25496eb3.js";import"./url.d7b430c5.js";import"./colorHelpers.9e2a2fd7.js";import"./PlayerConfigProvider.1e86cb18.js";import"./index.45b30c39.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="9f86630f-53b1-409d-9e53-9cf4b494663e",e._sentryDebugIdIdentifier="sentry-dbid-9f86630f-53b1-409d-9e53-9cf4b494663e")}catch{}})();export{u as default};
//# sourceMappingURL=App.46ba480c.js.map
