import{$ as t,r as d,o as s,c as r}from"./vue-router.25496eb3.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="c973d894-fe29-4ff4-8872-b98dd97d2579",e._sentryDebugIdIdentifier="sentry-dbid-c973d894-fe29-4ff4-8872-b98dd97d2579")}catch{}})();const c={};function _(e,o){const n=d("RouterView");return s(),r(n,{class:"router"})}const a=t(c,[["render",_],["__scopeId","data-v-3c2b9654"]]);export{a as default};
//# sourceMappingURL=Home.ae072430.js.map
