import{O as r}from"./workspaceStore.415b10dd.js";import{d as i,W as l,o as c,X as f,b as a,w as n,u as o,aF as d,dc as u,db as b}from"./vue-router.25496eb3.js";import"./url.d7b430c5.js";import"./colorHelpers.9e2a2fd7.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="5fb39e00-173f-4bd6-ac1f-d3b599f0976c",e._sentryDebugIdIdentifier="sentry-dbid-5fb39e00-173f-4bd6-ac1f-d3b599f0976c")}catch{}})();const w=i({__name:"OidcLoginCallback",setup(e){return l(async()=>{await new r().loginCallback()}),(t,s)=>(c(),f("div",null,[a(o(u),null,{default:n(()=>[d("You're authenticated")]),_:1}),a(o(b),null,{default:n(()=>[d(" This window should close automatically. Please close it manually if it doesn't. ")]),_:1})]))}});export{w as default};
//# sourceMappingURL=OidcLoginCallback.2f70e630.js.map
