import{P as m}from"./PlayerNavbar.30cbe349.js";import{u as f,i as g}from"./workspaceStore.415b10dd.js";import{d as h,eo as y,ea as i,e as v,f as k,r as w,o as c,X as b,u as n,c as L,R as I,a as N,b as C,$ as R}from"./vue-router.25496eb3.js";import"./metadata.b8c76de9.js";import"./PhBug.vue.ad71e707.js";import"./PhCheckCircle.vue.6921fc7d.js";import"./PhKanban.vue.6fea618a.js";import"./PhWebhooksLogo.vue.b74c61e7.js";import"./LoadingOutlined.ac39ec74.js";import"./PhSignOut.vue.e3cdd65d.js";import"./index.608a58cb.js";import"./Avatar.ec14bfae.js";import"./url.d7b430c5.js";import"./colorHelpers.9e2a2fd7.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[e]="5945eaaf-df75-4d87-960e-f16869835861",t._sentryDebugIdIdentifier="sentry-dbid-5945eaaf-df75-4d87-960e-f16869835861")}catch{}})();const V={class:"main-container"},x={class:"content"},B=h({__name:"Main",setup(t){const e=y(),o=f(),u=i().path,a=v(null),d=async({path:r,id:s})=>{a.value=s,await e.push({path:`/${r}`}),a.value=null},p=()=>{e.push({name:"playerLogin"})},l=k(()=>!!i().meta.hideLogin);return g(()=>e.push({name:"playerLogin"})),(r,s)=>{const _=w("RouterView");return c(),b("div",V,[n(o).state.workspace?(c(),L(m,{key:0,"current-path":n(u),"hide-login":l.value,"runner-data":n(o).state.workspace,loading:a.value,onNavigate:d,onLoginClick:p},null,8,["current-path","hide-login","runner-data","loading"])):I("",!0),N("section",x,[C(_)])])}}});const H=R(B,[["__scopeId","data-v-09fccc95"]]);export{H as default};
//# sourceMappingURL=Main.bca22017.js.map
