import{eM as t,eN as r}from"./vue-router.25496eb3.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="88ec9600-3cbe-4ce6-8f97-5b445d88f99d",e._sentryDebugIdIdentifier="sentry-dbid-88ec9600-3cbe-4ce6-8f97-5b445d88f99d")}catch{}})();function o(e,n){return t(1,arguments),r(e,Date.now(),n)}export{o as f};
//# sourceMappingURL=index.cdaff782.js.map
